summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index f8fa4f225c..1638578076 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -619,7 +619,7 @@ enum command_type
CMD_MAX_OVERMAP = CMD_MAP_EXIT_MAP,
- // targeting commands
+ // targetting commands
CMD_TARGET_DOWN_LEFT,
CMD_MIN_TARGET = CMD_TARGET_DOWN_LEFT,
CMD_TARGET_DOWN,
@@ -1514,7 +1514,7 @@ enum KeymapContext
{
KMC_DEFAULT, // For no-arg getchm(), must be zero.
KMC_LEVELMAP, // When in the 'X' level map
- KMC_TARGETING, // Only during 'x' and other targeting modes
+ KMC_TARGETTING, // Only during 'x' and other targetting modes
KMC_CONFIRM, // When being asked y/n/q questions
KMC_MENU, // For menus
#ifdef USE_TILE
@@ -2908,12 +2908,12 @@ enum stat_type
STAT_RANDOM = 255 // leave at 255, added for increase_stats() handling {dlb}
};
-enum targeting_type
+enum targetting_type
{
DIR_NONE,
DIR_TARGET,
DIR_DIR,
- DIR_TARGET_OBJECT // New as of 27-August-2009, for item-targeting spells
+ DIR_TARGET_OBJECT // New as of 27-August-2009, for item-targetting spells
};
enum torment_source_type